@@ -1,30 +1,16 @@
 
 # Utils -------------------------------------------------------------------
 
-#' Convert time-series data.frame to time-series object
+#' Interactive plot for time-series tibbles
 #'
-#' @param df data.frame or tibble, first column of name `datetime` being of class datetime and rest of columns being numeric
-#'
-#' @return xts time-series object
-#' @keywords internal
-#'
-#' @importFrom xts xts
-#'
-df_to_ts <- function(df) {
-  df <- df[!is.na(df[[1]]), ]
-  xts::xts(df[-1], order.by = df [[1]])
-}
-
-#' Plot a timeseries tibble in a Dygraphs HTML plot
-#'
-#' First column of the tibble must be a datetime or date variable.
-#' The rest of columns must be numeric of the same units.
+#' First column of the `df` tibble must be a `datetime` or date variable.
+#' The rest of columns must be numeric of the same units. This functions makes
+#' use of `dygraphs` package to generate an HTML Dygraphs plot.
 #'
 #' @param df data.frame or tibble, first column of name `datetime` being of class datetime and rest of columns being numeric
 #' @param title character, title of the plot (accepts HTML code)
 #' @param xlab character, X axis label (accepts HTML code)
 #' @param ylab character, Y axis label (accepts HTML code)
-#' @param group character, dygraphs group to associate this plot with. The x-axis zoom level of dygraphs plots within a group is automatically synchronized.
 #' @param legend_width integer, width (in pixels) of the div which shows the legend.
 #' @param ... extra arguments to pass to `dygraphs::dyOptions` function.
 #'
@@ -47,8 +33,8 @@ df_to_ts <- function(df) {
 #' )
 #' demand %>% plot_ts()
 #'
-plot_ts <- function(df, title = NULL, xlab = NULL, ylab = NULL, group = NULL, legend_width = 250,  ...) {
-  dygraph(df_to_ts(df), main = title, xlab = xlab, ylab = ylab, group = group) %>%
+plot_ts <- function(df, title = NULL, xlab = NULL, ylab = NULL, legend_width = 250,  ...) {
+  dygraph(df, main = title, xlab = xlab, ylab = ylab) %>%
     dyLegend(show = "always", width = legend_width) %>%
     dyOptions(...)
 }
@@ -144,7 +130,9 @@ expand_session <- function(session, resolution) {
 }
 
 
-#' Obtain time-series demand from sessions dataset
+#' Time-series EV demand
+#'
+#' Obtain time-series of EV demand from sessions data set
 #'
 #' @param sessions tibble, sessions data set in standard format marked by `{evprof}` package
 #' (see [this article](https://mcanigueral.github.io/evprof/articles/sessions-format.html))
@@ -157,7 +145,7 @@ expand_session <- function(session, resolution) {
 #' @param mc.cores integer, number of cores to use.
 #' Must be at least one, and parallelization requires at least two cores.
 #'
-#' @return tibble
+#' @return time-series tibble with first column of type `datetime`
 #' @export
 #'
 #' @importFrom dplyr tibble sym select_if group_by summarise arrange right_join distinct filter between
@@ -188,7 +176,7 @@ expand_session <- function(session, resolution) {
 #'   resolution = 60,
 #'   align_time = TRUE
 #' )
-#' demand %>% plot_ts()
+#' demand %>% plot_ts(ylab = "EV demand (kW)")
 #'
 #' # Get demand with a custom datetime sequence and resolution of 15 minutes
 #' sessions <- head(evsim::california_ev_sessions_profiles, 100)
@@ -204,7 +192,7 @@ expand_session <- function(session, resolution) {
 #'   resolution = 15,
 #'   align_time = TRUE
 #' )
-#' demand %>% plot_ts()
+#' demand %>% plot_ts(ylab = "EV demand (kW)")
 #'
 get_demand <- function(sessions, dttm_seq = NULL, by = "Profile", resolution = 15, align_time = FALSE, mc.cores = 1) {
 
@@ -314,7 +302,9 @@ get_demand <- function(sessions, dttm_seq = NULL, by = "Profile", resolution = 1
 
 # Occupancy ---------------------------------------------------------------
 
-#' Obtain time series of EV connected from sessions data set
+#' Time-series EV occupancy
+#'
+#' Obtain time-series of simultaneously connected EVs from sessions data set
 #'
 #' @param sessions tibble, sessions data set in standard format marked by `{evprof}` package
 #' (see [this article](https://mcanigueral.github.io/evprof/articles/sessions-format.html))
@@ -327,7 +317,7 @@ get_demand <- function(sessions, dttm_seq = NULL, by = "Profile", resolution = 1
 #' @param mc.cores integer, number of cores to use.
 #' Must be at least one, and parallelization requires at least two cores.
 #'
-#' @return tibble
+#' @return time-series tibble with first column of type `datetime`
 #' @export
 #'
 #' @importFrom dplyr tibble sym select_if group_by summarise arrange right_join distinct filter between
@@ -350,31 +340,30 @@ get_demand <- function(sessions, dttm_seq = NULL, by = "Profile", resolution = 1
 #'
 #' # Get occupancy with the complete datetime sequence from the sessions
 #' sessions <- head(evsim::california_ev_sessions, 100)
-#' connections <- get_n_connections(
+#' connections <- get_occupancy(
 #'   sessions,
-#'   by = "Session",
+#'   by = "ChargingStation",
 #'   resolution = 60,
 #'   align_time = TRUE
 #' )
-#' connections %>% plot_ts()
+#' connections %>% plot_ts(ylab = "Vehicles connected")
 #'
 #' # Get occupancy with a custom datetime sequence and resolution of 15 minutes
 #' sessions <- head(evsim::california_ev_sessions_profiles, 100)
 #' dttm_seq <- seq.POSIXt(
-#'   as_datetime(dmy(01102018)) %>% force_tz(tz(sessions$ConnectionStartDateTime)),
-#'   as_datetime(dmy(07102018)) %>% force_tz(tz(sessions$ConnectionStartDateTime)),
+#'   as_datetime(dmy(08102018)) %>% force_tz(tz(sessions$ConnectionStartDateTime)),
+#'   as_datetime(dmy(11102018)) %>% force_tz(tz(sessions$ConnectionStartDateTime)),
 #'   by = "15 mins"
 #' )
-#' connections <- get_n_connections(
+#' connections <- get_occupancy(
 #'   sessions,
 #'   dttm_seq = dttm_seq,
 #'   by = "Profile",
-#'   resolution = 15,
 #'   align_time = TRUE
 #' )
-#' connections %>% plot_ts()
+#' connections %>% plot_ts(ylab = "Vehicles connected")
 #'
-get_n_connections <- function(sessions, dttm_seq = NULL, by = "Profile", resolution = 15, align_time = FALSE, mc.cores = 1) {
+get_occupancy <- function(sessions, dttm_seq = NULL, by = "Profile", resolution = 15, align_time = FALSE, mc.cores = 1) {
 
   # Multi-processing parameter check
   if (mc.cores > detectCores(logical = FALSE) | mc.cores < 1) {
