@@ -7,7 +7,18 @@ library(lubridate)
 sessions <- evsim::california_ev_sessions %>%
   filter(year(ConnectionStartDateTime) == 2018, month(ConnectionStartDateTime) == 10)
 
+test_that("plot of occupancy duration curve works", {
+  expect_true(ggplot2::is.ggplot(
+    plot_occupancy_duration_curve(
+      sessions %>% mutate(Profile = "all"),
+      by = "Profile",
+      resolution = 15,
+      align_time = TRUE
+    )
+  ))
+})
+
 test_that("charging infrastructure sizing works", {
-  sessions_infrastructure <- add_charging_infrastructure(sessions, connections_th = 0)
+  sessions_infrastructure <- add_charging_infrastructure(sessions, duration_th = 0)
   expect_true(length(unique(sessions_infrastructure$ChargingStation)) > 1)
 })
